@@ -60,13 +60,20 @@ eog_image_viewer_factory (BonoboGenericFactory *this,
 }
 
 int main (int argc, char *argv [])					
-{									
+{	
+	CORBA_Object factory;
+								
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);                       
 	bind_textdomain_codeset (PACKAGE, "UTF-8");                     
 	textdomain (PACKAGE);                                           
 									
 	BONOBO_FACTORY_INIT ("eog-image-viewer", VERSION, &argc, argv);		
 									
-	return bonobo_generic_factory_main ("OAFIID:GNOME_EOG_Factory",
-					    eog_image_viewer_factory, NULL);	
+	factory = bonobo_activation_activate_from_id ("OAFIID:GNOME_EOG_Factory", Bonobo_ACTIVATION_FLAG_EXISTING_ONLY, NULL, NULL);
+
+	if (!factory) {
+		return bonobo_generic_factory_main ("OAFIID:GNOME_EOG_Factory",
+						    eog_image_viewer_factory, NULL);	
+	}
+	return 0;
 }                                                                       
